'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var client = require('@apollo/client');
var fetch = require('cross-fetch');
var middleware = require('@vue-storefront/middleware');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fetch__default = /*#__PURE__*/_interopDefaultLegacy(fetch);

const buildClient = (settings) => {
    // const errorLink = onError(({ graphQLErrors, networkError, operation }) => {
    //   if (graphQLErrors) {
    //     graphQLErrors.map((error) => logBuilder({label: '[GRAPHQL ERROR]', ...error, operation }));
    //   }
    //   if (networkError) {
    //     logBuilder({ label: '[NETWORK ERROR]', message: networkError });
    //   }
    // });
    const httpLink = client.createHttpLink({
        uri: settings.odooGraphqlUrl,
        credentials: 'include',
        fetch: fetch__default["default"],
        fetchOptions: settings.fetchOptions,
        // headers: {
        //   Cookie: settings.auth,
        //   'resquest-host': settings['resquest-host'],
        //   'REAL-IP': settings['real-ip']
        // }
    });
    const afterwareLink = new client.ApolloLink((operation, forward) => {
        return forward(operation).map((response) => {
            const context = operation.getContext();
            const authHeader = context.response.headers.get('set-cookie');
            if (response.data) {
                response.data.cookie = authHeader;
            }
            return response;
        });
    });
    const apolloLink = client.ApolloLink.from([
        //errorLink,
        afterwareLink.concat(httpLink)
    ]);
    return new client.ApolloClient({
        link: apolloLink,
        cache: new client.InMemoryCache(),
        defaultOptions: {
            query: {
                errorPolicy: "all",
                fetchPolicy: "no-cache",
            },
            mutate: {
                errorPolicy: "all",
            }
        }
    });
};

var productFragment = `
  id
  firstVariant{
    id
    combinationInfoVariant
    slug
    variantAttributeValues{
      id
      name
      attribute{
        id
        name
      }
    }
  }
  smallImage
  price
  name
  description
  image
  imageFilename
  combinationInfo
  slug
  sku
  jsonLd
  isInWishlist
  categories {
    id
    name
    slug
    parent{
      parent{
        id
      }
    }
  }
  attributeValues {
    id
    name
    displayType
    priceExtra
    attribute {
      id
      name
    }
    search
  }
`;

var query$4 = client.gql `
    query TemplateProduct($id: Int, $slug: String, $barcode: String) {
        product(id: $id, slug: $slug, barcode: $barcode) {
            ${productFragment}
        }
    }`;

const getProductTemplate = async (context, params, customQuery) => {
    const { getProductTemplate } = context.extendQuery(customQuery, { getProductTemplate: { query: query$4, variables: params }
    });
    const response = await context.client.query({
        variables: getProductTemplate.variables,
        query: getProductTemplate.query,
    });
    return response;
};

var query$3 = client.gql `
    query TemplateProductList(
    $filter: ProductFilterInput
    $currentPage: Int
    $pageSize: Int = 5
    $search: String
    $sort: ProductSortInput
    ) {
    products(
        filter: $filter
        currentPage: $currentPage
        pageSize: $pageSize
        search: $search
        sort: $sort
    ) {
        totalCount
        attributeValues {
        id
        name
        displayType
        name
        htmlColor
        search
        attribute{
            id
            name
        }
        
        }
        products {
        ${productFragment}
        }
    }
}`;

const getProductTemplateList = async (context, params, customQuery) => {
    const { getProductTemplateList } = context.extendQuery(customQuery, { getProductTemplateList: { query: query$3, variables: params }
    });
    const response = await context.client.query({
        variables: getProductTemplateList.variables,
        query: getProductTemplateList.query
    });
    return response;
};

var query$2 = client.gql `
query Category($slug: String, $id: Int) {
    category(slug: $slug, id: $id) {
        id
        name
        slug
        childs {
          id
          name
          slug
          childs {
            id
            name
            slug
          }
        }
      }
  }
`;

const getCategory = async (context, params, customQuery) => {
    const { getCategory } = context.extendQuery(customQuery, { getCategory: { query: query$2, variables: params } });
    const response = await context.client.query({
        variables: getCategory.variables,
        query: getCategory.query,
    });
    return response;
};

var query$1 = client.gql `
query CategoryList(
    $search: String
    $filter: CategoryFilterInput
    $currentPage: Int
    $pageSize: Int
    $sort: CategorySortInput
  ) {
    categories(
      search: $search
      filter: $filter
      currentPage: $currentPage
      pageSize: $pageSize
      sort: $sort
    ) {
      categories {
        id
        name
        slug
        childs {
          id
          name
          slug
          childs {
            id
            name
            slug
          }
        }
        parent {
          id
          name
          slug
          parent {
            id
            name
            slug
            childs {
              id
              name
              slug
              childs {
                id
                name
                slug
              }
            }
          }
        }
      }
    }
  }`;

const getCategoryList = async (context, params, customQuery) => {
    const { getCategoryList } = context.extendQuery(customQuery, { getCategoryList: { query: query$1, variables: params }
    });
    const response = await context.client.query({
        variables: getCategoryList.variables,
        query: getCategoryList.query
    });
    return response;
};

var query = client.gql `
    query ProductVariant($productTemplateId: Int, $combinationId: [Int]) {
        productVariant( productTemplateId: $productTemplateId combinationId: $combinationId) {
            product {
                id
                image
                variantPrice
                variantPriceAfterDiscount
                variantHasDiscountedPrice
            }
            productTemplateId
            displayName
            price
            listPrice
            hasDiscountedPrice
        }
    }`;

const getProductVariant = async (context, params, customQuery) => {
    const { getProductVariant } = context.extendQuery(customQuery, { getProductVariant: { query, variables: params }
    });
    const response = await context.client.query({
        variables: getProductVariant.variables,
        query: getProductVariant.query,
    });
    return response;
};

var apiEndpoints = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getProductTemplate: getProductTemplate,
  getProductTemplateList: getProductTemplateList,
  getCategory: getCategory,
  getCategoryList: getCategoryList,
  getProductVariant: getProductVariant
});

const onCreate = (settings) => {
    const client = buildClient(settings);
    return {
        config: settings,
        client
    };
};
const { createApiClient } = middleware.apiClientFactory({
    onCreate,
    api: apiEndpoints
});

exports.createApiClient = createApiClient;
//# sourceMappingURL=index.js.map
